==> EOxServer-1.0.0rc36.tar.gz: EOxServer-1.0.0rc36/eoxserver/services/urls.py <==
#-------------------------------------------------------------------------------
#
# Project: EOxServer <http://eoxserver.org>
# Authors: Fabian Schindler <fabian.schindler@eox.at>
#
#-------------------------------------------------------------------------------
# Copyright (C) 2014 EOX IT Services GmbH
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies of this Software or works derived from this Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
#-------------------------------------------------------------------------------

try:
    from django.conf.urls import url as re_path
except ImportError:
    from django.urls import re_path
try:
    from django.core.urlresolvers import reverse
except ImportError:
    from django.urls import reverse

from eoxserver.services import views

urlpatterns = [
    re_path(r'^$', views.ows, name='ows')
]


def get_http_service_url(request=None):
    """ Returns the URL the OWS view is available under. If a
        :class:`django.http.HttpRequest` is passed, an absolute URL is
        constructed with the request information.
    """

    http_service_url = reverse("ows")
    if request:
        http_service_url = request.build_absolute_uri(http_service_url)
    return http_service_url

==> EOxServer-1.1.4.dev11.tar.gz: EOxServer-1.1.4.dev11/eoxserver/services/urls.py <==
#-------------------------------------------------------------------------------
#
# Project: EOxServer <http://eoxserver.org>
# Authors: Fabian Schindler <fabian.schindler@eox.at>
#
#-------------------------------------------------------------------------------
# Copyright (C) 2014 EOX IT Services GmbH
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies of this Software or works derived from this Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
#-------------------------------------------------------------------------------

try:
    from django.conf.urls import url as re_path
except ImportError:
    from django.urls import re_path
try:
    from django.core.urlresolvers import reverse
except ImportError:
    from django.urls import reverse

from eoxserver.services import views

urlpatterns = [
    re_path(r'^$', views.ows, name='ows',)
]


def get_http_service_url(request=None):
    """ Returns the URL the OWS view is available under. If a
        :class:`django.http.HttpRequest` is passed, an absolute URL is
        constructed with the request information.
    """

    http_service_url = reverse("ows")
    if request:
        http_service_url = request.build_absolute_uri(http_service_url)
    return http_service_url
